#' GBIF data for a clade of Iberolacerta lizards from spain
#'
#' This is some sample data downloaded from GBIF for the purposes of demonstrating ENMTools functionality.
#'
#'
#' @docType data
#' @keywords datasets
#' @name iberolacerta.clade
#' @usage iberolacerta.clade
#' @format An enmtools.clade object with seven species and a phylogeny.
#' @export
NULL
